Module git_export

Module git_export 

Export Heddle states to Git commits functionality.

Structs

ExportStateOptions

Functions

commit_is_byte_faithful
Whether reconstructing state’s commit object from Heddle state alone is guaranteed byte-exact to the original commit — the precondition for the #567 reconstruct-from-state path. False for the two #564 lossy gaps:
export_all
Export all Heddle states to Git commits.
export_current_thread
Export one Heddle thread to its matching Git branch.
export_state
Export a single state to Git for audience.
export_tree
Export a Heddle tree to Git.
git_remote_names
is_remote_tracking_thread_name